@@ -13,17 +13,15 @@ set.seed(2219, kind = "Mersenne-Twister")
 data(Orange)
 Orange[, 4:10] <- rnorm(7*nrow(Orange))
 orange.vsurf <- VSURF(circumference~., Orange, ntree = 100, nfor.thres = 20,
-                      nfor.interp = 10, nfor.pred = 10)
+                      nfor.interp = 10, nfor.pred = 10, verbose = FALSE)
 
 test_that("Selected variables for the 3 steps", {
-  skip("skip")
   expect_identical(orange.vsurf$varselect.thres, c(2L, 1L, 5L))
   expect_identical(orange.vsurf$varselect.interp, c(2L, 1L))
   expect_identical(orange.vsurf$varselect.pred, 2L)
 })
 
 test_that("Variable importance",{
-  skip("skip")
   expect_equal(orange.vsurf$imp.mean.dec,
                if (!is.win32b(platform))
                  c(3066.1367959, 192.6666525, 118.7935090, 11.6102848, 0.9062662,
@@ -45,7 +43,6 @@ test_that("Variable importance",{
 })
 
 test_that("OOB erros of nested models", {
-  skip("skip")
   expect_equal(orange.vsurf$err.interp,
                if (!is.win32b(platform))
                  c(719.6904, 464.9525, 784.7824) else
@@ -56,7 +53,6 @@ test_that("OOB erros of nested models", {
 })
 
 test_that("Thresholds for the 3 steps", {
-  skip("skip")
   expect_equal(min(orange.vsurf$pred.pruned.tree),
                ifelse(!is.win32b(platform), 42.07285, 52.33703),
                tolerance = 1e-5)
